# perceptron_pypi
perceptron_pypi

## How to use this
```python
from oneneuron.perceptron import Perceptron

## get X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)
```

# Reference -
[official python docs for pypi] (https://packaging.python.org/tutorials/packaging-projects/)

[github docs for github actions] (https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)

![GIF File](https://camo.githubusercontent.com/f5a097583cacf8802bae4d0544548a8e29bed6aa7e3c1c73d15da80a709008a5/68747470733a2f2f6d6f7276616e7a686f752e6769746875622e696f2f7374617469632f726573756c74732f74656e736f72666c6f772f355f31355f30312e676966)